# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.assistance import task_storage_service_pb2 as avikom_dot_assistance_dot_task__storage__service__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class TaskStorageServiceStub(object):
    """*
    This services stores scene, task and task step definitions.
    It should not actively alter any of the provided data though.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddScene = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/AddScene',
                request_serializer=avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.UpdateScene = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/UpdateScene',
                request_serializer=avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetScene = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetScene',
                request_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
                )
        self.GetAllScenes = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetAllScenes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.SceneList.FromString,
                )
        self.AddTask = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/AddTask',
                request_serializer=avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.UpdateTask = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/UpdateTask',
                request_serializer=avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetTask = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetTask',
                request_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_task__pb2.Task.FromString,
                )
        self.GetAllTasks = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetAllTasks',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskList.FromString,
                )
        self.AddTaskStep = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/AddTaskStep',
                request_serializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.UpdateTaskStep = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/UpdateTaskStep',
                request_serializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.GetTaskStep = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetTaskStep',
                request_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.FromString,
                )
        self.GetAllTaskSteps = channel.unary_unary(
                '/avikom.assistance.TaskStorageService/GetAllTaskSteps',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStepList.FromString,
                )


class TaskStorageServiceServicer(object):
    """*
    This services stores scene, task and task step definitions.
    It should not actively alter any of the provided data though.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def AddScene(self, request, context):
        """/ adds a scene to the storage; raises an error if the scene already exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateScene(self, request, context):
        """/ updates an existing scene; will raise an error when the scene does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScene(self, request, context):
        """/ returns a scene with name equals to `name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllScenes(self, request, context):
        """/ returns a list of all currently available scenes; fields such as task will be completely resolved
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTask(self, request, context):
        """/ adds a task to the storage; raises an error if the task already exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTask(self, request, context):
        """/ updates an existing task; will raise an error when the task does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """/ returns a task with name equals to `name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllTasks(self, request, context):
        """/ returns a list of all currently available tasks; fields such as steps will be completely resolved
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTaskStep(self, request, context):
        """/ adds a task step to the storage; raises an error if the step already exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTaskStep(self, request, context):
        """/ updates an existing task step; will raise an error when the step does not exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskStep(self, request, context):
        """/ returns a task step with name equals to `name`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllTaskSteps(self, request, context):
        """/ returns a list of task steps
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TaskStorageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddScene': grpc.unary_unary_rpc_method_handler(
                    servicer.AddScene,
                    request_deserializer=avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'UpdateScene': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateScene,
                    request_deserializer=avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetScene': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScene,
                    request_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
            ),
            'GetAllScenes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllScenes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.SceneList.SerializeToString,
            ),
            'AddTask': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTask,
                    request_deserializer=avikom_dot_assistance_dot_task__pb2.Task.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'UpdateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTask,
                    request_deserializer=avikom_dot_assistance_dot_task__pb2.Task.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
            ),
            'GetAllTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllTasks,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskList.SerializeToString,
            ),
            'AddTaskStep': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTaskStep,
                    request_deserializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'UpdateTaskStep': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTaskStep,
                    request_deserializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'GetTaskStep': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskStep,
                    request_deserializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.FromString,
                    response_serializer=avikom_dot_assistance_dot_task__step__pb2.TaskStep.SerializeToString,
            ),
            'GetAllTaskSteps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllTaskSteps,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_assistance_dot_task__storage__service__pb2.TaskStepList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.assistance.TaskStorageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TaskStorageService(object):
    """*
    This services stores scene, task and task step definitions.
    It should not actively alter any of the provided data though.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def AddScene(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/AddScene',
            avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateScene(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/UpdateScene',
            avikom_dot_assistance_dot_scene__pb2.Scene.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetScene(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetScene',
            avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
            avikom_dot_assistance_dot_scene__pb2.Scene.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllScenes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetAllScenes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_assistance_dot_task__storage__service__pb2.SceneList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/AddTask',
            avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/UpdateTask',
            avikom_dot_assistance_dot_task__pb2.Task.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetTask',
            avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
            avikom_dot_assistance_dot_task__pb2.Task.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetAllTasks',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_assistance_dot_task__storage__service__pb2.TaskList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTaskStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/AddTaskStep',
            avikom_dot_assistance_dot_task__step__pb2.TaskStep.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTaskStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/UpdateTaskStep',
            avikom_dot_assistance_dot_task__step__pb2.TaskStep.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetTaskStep',
            avikom_dot_assistance_dot_task__storage__service__pb2.TaskStorageQuery.SerializeToString,
            avikom_dot_assistance_dot_task__step__pb2.TaskStep.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllTaskSteps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.assistance.TaskStorageService/GetAllTaskSteps',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_assistance_dot_task__storage__service__pb2.TaskStepList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssetBundleInfo(google.protobuf.message.Message):
    """*
    A message header to send Unity asset bundles in chunks.
    Should be available in every initial message to an asset bunde receiver.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CHUNK_SIZE_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    size: builtins.int
    """/ size of the whole bundle in bytes"""
    chunk_size: builtins.int
    """/ the planed size of each data chunk"""
    bundle_name: builtins.str
    """/ globally unique name of the asset bundle in question"""
    version: builtins.str
    """/ version of the bundle to determine whether sending binary data is required or not"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        chunk_size: builtins.int = ...,
        bundle_name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bundle_name", b"bundle_name", "chunk_size", b"chunk_size", "size", b"size", "version", b"version"]) -> None: ...

global___AssetBundleInfo = AssetBundleInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ContentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTENT_UNKNOWN: _ContentType.ValueType  # 0
    """/ no content type specified; should not be used actively"""
    CONTENT_IMAGE: _ContentType.ValueType  # 1
    """/ shows 2-D images"""
    CONTENT_VIDEO: _ContentType.ValueType  # 2
    """/ shows videos"""
    CONTENT_TEXT: _ContentType.ValueType  # 3
    """/ shows instructions in text form; is also used to generate speech output if ssml is not defined"""
    CONTENT_AUDIO: _ContentType.ValueType  # 4
    """/ plays audio (e.g. background music)"""
    CONTENT_VISUAL: _ContentType.ValueType  # 5
    """/ shows images or holograms situated in space"""
    CONTENT_EXTERNAL: _ContentType.ValueType  # 6
    """/ will be opened with the default OS application"""
    CONTENT_SSML: _ContentType.ValueType  # 7
    """/ is used for enhanced tts output"""

class ContentType(_ContentType, metaclass=_ContentTypeEnumTypeWrapper):
    """*
    Defines the type of an Instruction.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

CONTENT_UNKNOWN: ContentType.ValueType  # 0
"""/ no content type specified; should not be used actively"""
CONTENT_IMAGE: ContentType.ValueType  # 1
"""/ shows 2-D images"""
CONTENT_VIDEO: ContentType.ValueType  # 2
"""/ shows videos"""
CONTENT_TEXT: ContentType.ValueType  # 3
"""/ shows instructions in text form; is also used to generate speech output if ssml is not defined"""
CONTENT_AUDIO: ContentType.ValueType  # 4
"""/ plays audio (e.g. background music)"""
CONTENT_VISUAL: ContentType.ValueType  # 5
"""/ shows images or holograms situated in space"""
CONTENT_EXTERNAL: ContentType.ValueType  # 6
"""/ will be opened with the default OS application"""
CONTENT_SSML: ContentType.ValueType  # 7
"""/ is used for enhanced tts output"""
global___ContentType = ContentType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.math.vector3d_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Waypoint(google.protobuf.message.Message):
    """*
    This describes a point in space and its conceptual neighbours.
    Waypoints are used to savely guide users from one location to another.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NEIGHBORS_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ waypoint name to be adressable"""
    @property
    def location(self) -> avikom.math.vector3d_pb2.Vector3D:
        """/ location of the waypoint in world coordinates"""
    @property
    def neighbors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ neightbouring waypoints; if not set they might be derived from other waypoint neighbourhood relationships"""
    threshold: builtins.float
    """/ a 'bubble' (in meters) around a waypoint that determines when a waypoint is considered reached"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        location: avikom.math.vector3d_pb2.Vector3D | None = ...,
        neighbors: collections.abc.Iterable[builtins.str] | None = ...,
        threshold: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "neighbors", b"neighbors", "threshold", b"threshold"]) -> None: ...

global___Waypoint = Waypoint



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/split_procedure_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.math import float_matrix_pb2 as avikom_dot_math_dot_float__matrix__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.avikom/assistance/split_procedure_result.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x19\x61vikom/generic/user.proto\x1a\x1e\x61vikom/math/float_matrix.proto\"\x91\x01\n\x14SplitProcedureResult\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.avikom.generic.User\x12%\n\x04task\x18\x02 \x01(\x0b\x32\x17.avikom.assistance.Task\x12(\n\x06matrix\x18\x03 \x01(\x0b\x32\x18.avikom.math.FloatMatrix:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.split_procedure_result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SPLITPROCEDURERESULT._options = None
  _SPLITPROCEDURERESULT._serialized_options = b'\210\265\030\001'
  _SPLITPROCEDURERESULT._serialized_start=189
  _SPLITPROCEDURERESULT._serialized_end=334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import issue_pb2 as avikom_dot_assistance_dot_issue__pb2
from avikom.assistance import issue_query_pb2 as avikom_dot_assistance_dot_issue__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/assistance/issue_service.proto\x12\x11\x61vikom.assistance\x1a\x1b\x61vikom/generic/result.proto\x1a\x1d\x61vikom/assistance/issue.proto\x1a#avikom/assistance/issue_query.proto\x1a\x1cgoogle/api/annotations.proto2\xa0\x01\n\x0cIssueService\x12\x45\n\nStartIssue\x12\x1d.avikom.assistance.IssueQuery\x1a\x16.avikom.generic.Result\"\x00\x12I\n\x08GetIssue\x12\x1d.avikom.assistance.IssueQuery\x1a\x1c.avikom.assistance.IssueList\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUESERVICE._serialized_start=188
  _ISSUESERVICE._serialized_end=348
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_state_change.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import runtime_step_state_pb2 as avikom_dot_assistance_dot_runtime__step__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1avikom/assistance/runtime_step_state_change.proto\x12\x11\x61vikom.assistance\x1a*avikom/assistance/runtime_step_state.proto\"X\n\x16RuntimeStepStateChange\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.avikom.assistance.RuntimeStepStateBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_state_change_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPSTATECHANGE._serialized_start=116
  _RUNTIMESTEPSTATECHANGE._serialized_end=204
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.key_value_pair_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServiceConfiguration(google.protobuf.message.Message):
    """*
    A message that combines peer topics and related service configurations meant for TaskStep definitions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    topic: builtins.str
    """/ topic related to this service"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ key-value pairs to configure the requested service"""
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
        parameters: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "topic", b"topic"]) -> None: ...

global___ServiceConfiguration = ServiceConfiguration



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.issue_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IssueQuery(google.protobuf.message.Message):
    """*
    Query an issue from the storage or the session manager. Fields can be combined and intersections will be returned.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ when set, the IssueList will only contain one element or an error is raised"""
    status: avikom.assistance.issue_pb2.IssueStatus.ValueType
    """/ when set, only issues with this status will be returned"""
    user_id: builtins.int
    """/ when set, only issues assigned to the user will be returned"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        status: avikom.assistance.issue_pb2.IssueStatus.ValueType = ...,
        user_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "status", b"status", "user_id", b"user_id"]) -> None: ...

global___IssueQuery = IssueQuery



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.choice_item_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ChoicesConfig(google.protobuf.message.Message):
    """*
    This message describes a choice a peer/user can make.
    It contains state information for each individual choice that can be made
    to enable multiple selections in a looped interaction.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.choice_item_pb2.ChoiceItem]:
        """a list of choices to choose from"""
    default_value: builtins.str
    """If set, this value may be returned when no choice has been made. If not, a valid item value must be returned."""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[avikom.assistance.choice_item_pb2.ChoiceItem] | None = ...,
        default_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "items", b"items"]) -> None: ...

global___ChoicesConfig = ChoicesConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ErrorCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ErrorCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ErrorCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_ERROR: _ErrorCode.ValueType  # 0
    """/ default value when no error occured or the error was not specified"""
    INTERNAL_ERROR: _ErrorCode.ValueType  # 1
    """/ errors on server side that cannot be solved by client"""
    ATTRIBUTE_ERROR: _ErrorCode.ValueType  # 2
    """/ errors with regard to the attributes of the request"""
    VALUE_ERROR: _ErrorCode.ValueType  # 3
    """/ one or more attribute values provided were not valid"""
    RUNTIME_ERROR: _ErrorCode.ValueType  # 4
    """/ the error occured unexpectedly during execution of program"""
    NOT_IMPLEMENTED_ERROR: _ErrorCode.ValueType  # 5
    """/ returned if service called is not implemented on server side"""

class ErrorCode(_ErrorCode, metaclass=_ErrorCodeEnumTypeWrapper): ...

NO_ERROR: ErrorCode.ValueType  # 0
"""/ default value when no error occured or the error was not specified"""
INTERNAL_ERROR: ErrorCode.ValueType  # 1
"""/ errors on server side that cannot be solved by client"""
ATTRIBUTE_ERROR: ErrorCode.ValueType  # 2
"""/ errors with regard to the attributes of the request"""
VALUE_ERROR: ErrorCode.ValueType  # 3
"""/ one or more attribute values provided were not valid"""
RUNTIME_ERROR: ErrorCode.ValueType  # 4
"""/ the error occured unexpectedly during execution of program"""
NOT_IMPLEMENTED_ERROR: ErrorCode.ValueType  # 5
"""/ returned if service called is not implemented on server side"""
global___ErrorCode = ErrorCode

@typing_extensions.final
class Result(google.protobuf.message.Message):
    """*
    A message to provide feedback about sucessful or failed remote procedure calls
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """/ true if sucessful, false otherwise"""
    message: builtins.str
    """/ additional semantic information; specifying what went wrong or communicate results of successful operations"""
    error: global___ErrorCode.ValueType
    """/ specifies the type of error that occured; will only be set if success is false"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        message: builtins.str = ...,
        error: global___ErrorCode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "message", b"message", "success", b"success"]) -> None: ...

global___Result = Result



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.glasses.interaction_type_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InteractionEvent(google.protobuf.message.Message):
    """*
    This message describes a user interaction with a virtual or real-world artifact.
    The kind and target of an interaction is communicated.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    type: avikom.glasses.interaction_type_pb2.InteractionType.ValueType
    """/ type of interaction (e.g. click, touch, drag)"""
    target: builtins.str
    """/ the unique name of the targt object"""
    def __init__(
        self,
        *,
        type: avikom.glasses.interaction_type_pb2.InteractionType.ValueType = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___InteractionEvent = InteractionEvent



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SpacePinNames(google.protobuf.message.Message):
    """*
    A list of all calibration objects/space pin names.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ list of names"""
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names"]) -> None: ...

global___SpacePinNames = SpacePinNames



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import key_value_pair_pb2 as avikom_dot_generic_dot_key__value__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/assistance/issue.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x1c\x61vikom/options/options.proto\x1a\x19\x61vikom/generic/user.proto\x1a#avikom/generic/key_value_pair.proto\"\xdc\x02\n\x05Issue\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12$\n\x06issuer\x18\x02 \x01(\x0b\x32\x14.avikom.generic.User\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\'\n\x05scene\x18\x04 \x01(\x0b\x32\x18.avikom.assistance.Scene\x12%\n\x04task\x18\x05 \x01(\x0b\x32\x17.avikom.assistance.Task\x12%\n\x07include\x18\x06 \x03(\x0b\x32\x14.avikom.generic.User\x12%\n\x07\x65xclude\x18\x07 \x03(\x0b\x32\x14.avikom.generic.User\x12\x30\n\nparameters\x18\x08 \x03(\x0b\x32\x1c.avikom.generic.KeyValuePair\x12.\n\x06status\x18\t \x01(\x0e\x32\x1e.avikom.assistance.IssueStatus:\x04\x88\xb5\x18\x01\"5\n\tIssueList\x12(\n\x06issues\x18\x01 \x03(\x0b\x32\x18.avikom.assistance.Issue*|\n\x0bIssueStatus\x12\x11\n\rISSUE_UNKNOWN\x10\x00\x12\x0e\n\nISSUE_OPEN\x10\x01\x12\x12\n\x0eISSUE_ASSIGNED\x10\x05\x12\x10\n\x0cISSUE_ACTIVE\x10\x07\x12\x10\n\x0cISSUE_CLOSED\x10\n\x12\x12\n\x0eISSUE_REJECTED\x10\x0b\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUE.fields_by_name['id']._options = None
  _ISSUE.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _ISSUE._options = None
  _ISSUE._serialized_options = b'\210\265\030\001'
  _ISSUESTATUS._serialized_start=613
  _ISSUESTATUS._serialized_end=737
  _ISSUE._serialized_start=208
  _ISSUE._serialized_end=556
  _ISSUELIST._serialized_start=558
  _ISSUELIST._serialized_end=611
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.unity.game_object_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TaskConfig(google.protobuf.message.Message):
    """*
    This message describes a task config and contains context-specific objects.
    All assets should have a parent that represents their location within a scene.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_NAME_FIELD_NUMBER: builtins.int
    ASSETS_FIELD_NUMBER: builtins.int
    task_name: builtins.str
    """/ name of the task that is configured"""
    @property
    def assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.unity.game_object_pb2.GameObject]:
        """/ a list of assets that represent (virtual) task-specific assets"""
    def __init__(
        self,
        *,
        task_name: builtins.str = ...,
        assets: collections.abc.Iterable[avikom.unity.game_object_pb2.GameObject] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assets", b"assets", "task_name", b"task_name"]) -> None: ...

global___TaskConfig = TaskConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.unity.transpose_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GameObject(google.protobuf.message.Message):
    """*
    This message describes a (virtual) object in the current scene.
    Properties have been chosen to allo Unity-based peers to create instances from such a message.
    However, this message might also be used in contexts where rendering is not necessary.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TRANSPOSE_FIELD_NUMBER: builtins.int
    PREFAB_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ scene name of the object"""
    @property
    def transpose(self) -> avikom.unity.transpose_pb2.Transpose:
        """/ the pose of the object relative to its parent"""
    prefab: builtins.str
    """/ addressable uri of the (audio)visual appearance blueprint/prefab"""
    parent: builtins.str
    """/ the parent's name; if not set, an object will be attached to the scene's root or an equivalent group"""
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GameObject]:
        """/ a list of nested `GameObjects`; parent will be this object if not stated differently"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        transpose: avikom.unity.transpose_pb2.Transpose | None = ...,
        prefab: builtins.str = ...,
        parent: builtins.str = ...,
        children: collections.abc.Iterable[global___GameObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["transpose", b"transpose"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["children", b"children", "name", b"name", "parent", b"parent", "prefab", b"prefab", "transpose", b"transpose"]) -> None: ...

global___GameObject = GameObject



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Protocol:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Protocol.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROTOCOL_TCP: _Protocol.ValueType  # 0
    PROTOCOL_WEBSOCKET: _Protocol.ValueType  # 1

class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper): ...

PROTOCOL_TCP: Protocol.ValueType  # 0
PROTOCOL_WEBSOCKET: Protocol.ValueType  # 1
global___Protocol = Protocol

class _VideoQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoQuality.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUALITY_VIDEO_NONE: _VideoQuality.ValueType  # 0
    QUALITY_VIDEO_LOWEST: _VideoQuality.ValueType  # 1
    QUALITY_VIDEO_DEFAULT: _VideoQuality.ValueType  # 5
    QUALITY_VIDEO_HIGHEST: _VideoQuality.ValueType  # 10

class VideoQuality(_VideoQuality, metaclass=_VideoQualityEnumTypeWrapper): ...

QUALITY_VIDEO_NONE: VideoQuality.ValueType  # 0
QUALITY_VIDEO_LOWEST: VideoQuality.ValueType  # 1
QUALITY_VIDEO_DEFAULT: VideoQuality.ValueType  # 5
QUALITY_VIDEO_HIGHEST: VideoQuality.ValueType  # 10
global___VideoQuality = VideoQuality

class _AudioQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AudioQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AudioQuality.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUALITY_AUDIO_NONE: _AudioQuality.ValueType  # 0
    QUALITY_AUDIO_LOWEST: _AudioQuality.ValueType  # 1
    QUALITY_AUDIO_DEFAULT: _AudioQuality.ValueType  # 5
    QUALITY_AUDIO_HIGHEST: _AudioQuality.ValueType  # 10

class AudioQuality(_AudioQuality, metaclass=_AudioQualityEnumTypeWrapper): ...

QUALITY_AUDIO_NONE: AudioQuality.ValueType  # 0
QUALITY_AUDIO_LOWEST: AudioQuality.ValueType  # 1
QUALITY_AUDIO_DEFAULT: AudioQuality.ValueType  # 5
QUALITY_AUDIO_HIGHEST: AudioQuality.ValueType  # 10
global___AudioQuality = AudioQuality

@typing_extensions.final
class StreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    AUDIO_QUALITY_FIELD_NUMBER: builtins.int
    VIDEO_QUALITY_FIELD_NUMBER: builtins.int
    SEND_AUGMENTED_FIELD_NUMBER: builtins.int
    RECEIVE_AUDIO_FIELD_NUMBER: builtins.int
    RECEIVE_VIDEO_FIELD_NUMBER: builtins.int
    protocol: global___Protocol.ValueType
    audio_quality: global___AudioQuality.ValueType
    video_quality: global___VideoQuality.ValueType
    send_augmented: builtins.bool
    receive_audio: builtins.bool
    receive_video: builtins.bool
    def __init__(
        self,
        *,
        protocol: global___Protocol.ValueType = ...,
        audio_quality: global___AudioQuality.ValueType = ...,
        video_quality: global___VideoQuality.ValueType = ...,
        send_augmented: builtins.bool = ...,
        receive_audio: builtins.bool = ...,
        receive_video: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_quality", b"audio_quality", "protocol", b"protocol", "receive_audio", b"receive_audio", "receive_video", b"receive_video", "send_augmented", b"send_augmented", "video_quality", b"video_quality"]) -> None: ...

global___StreamRequest = StreamRequest



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class RemoteControlServiceStub(object):
    """*
    An interface to allow other peers to (automatically) control GUI elements.
    A `RemoteControlService` must know the concepts of a `StepBrowser` and the central introduction hub.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ShowStepBrowser = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/ShowStepBrowser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.HideStepBrowser = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/HideStepBrowser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.ShowNextStep = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/ShowNextStep',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.ShowPreviousStep = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/ShowPreviousStep',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.ShowNextMedia = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/ShowNextMedia',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.ShowPreviousMedia = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/ShowPreviousMedia',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.PlayMedia = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/PlayMedia',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.PauseMedia = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/PauseMedia',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )
        self.StopMedia = channel.unary_unary(
                '/avikom.glasses.RemoteControlService/StopMedia',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_result__pb2.Result.FromString,
                )


class RemoteControlServiceServicer(object):
    """*
    An interface to allow other peers to (automatically) control GUI elements.
    A `RemoteControlService` must know the concepts of a `StepBrowser` and the central introduction hub.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def ShowStepBrowser(self, request, context):
        """/ enable the step browser
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HideStepBrowser(self, request, context):
        """/ disable the step prowser
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowNextStep(self, request, context):
        """/ show next step in the step browser
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowPreviousStep(self, request, context):
        """/ show previous step in the step browser
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowNextMedia(self, request, context):
        """/ show the next media file in the control hub
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowPreviousMedia(self, request, context):
        """/ show the previous media file in the control hub
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayMedia(self, request, context):
        """/ play the currently active media file if applicable
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseMedia(self, request, context):
        """/ pause the currently shown media file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopMedia(self, request, context):
        """/ stops the currently shown media file; may also be called while a media file is paused
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RemoteControlServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ShowStepBrowser': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowStepBrowser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'HideStepBrowser': grpc.unary_unary_rpc_method_handler(
                    servicer.HideStepBrowser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'ShowNextStep': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowNextStep,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'ShowPreviousStep': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowPreviousStep,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'ShowNextMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowNextMedia,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'ShowPreviousMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowPreviousMedia,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'PlayMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayMedia,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'PauseMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseMedia,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
            'StopMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.StopMedia,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=avikom_dot_generic_dot_result__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.glasses.RemoteControlService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RemoteControlService(object):
    """*
    An interface to allow other peers to (automatically) control GUI elements.
    A `RemoteControlService` must know the concepts of a `StepBrowser` and the central introduction hub.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def ShowStepBrowser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/ShowStepBrowser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HideStepBrowser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/HideStepBrowser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowNextStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/ShowNextStep',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowPreviousStep(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/ShowPreviousStep',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowNextMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/ShowNextMedia',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowPreviousMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/ShowPreviousMedia',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/PlayMedia',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/PauseMedia',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.glasses.RemoteControlService/StopMedia',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            avikom_dot_generic_dot_result__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tracking/location_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import vector3d_pb2 as avikom_dot_math_dot_vector3d__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&avikom/tracking/location_service.proto\x12\x0f\x61vikom.tracking\x1a\x1a\x61vikom/math/vector3d.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1bgoogle/protobuf/empty.proto\"B\n\rTargetRequest\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x10\n\x08sleep_ms\x18\x02 \x01(\x05\x12\x0f\n\x07watcher\x18\x03 \x01(\t2\xb2\x01\n\x0fLocationService\x12M\n\x10GetScenePosition\x12\x1e.avikom.tracking.TargetRequest\x1a\x15.avikom.math.Vector3D\"\x00\x30\x01\x12P\n\x13GetRelativePosition\x12\x1e.avikom.tracking.TargetRequest\x1a\x15.avikom.math.Vector3D\"\x00\x30\x01\x42o\n\x19\x61pp.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\xaa\x02\x15\x41vikom.Types.Trackingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tracking.location_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031app.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\252\002\025Avikom.Types.Tracking'
  _TARGETREQUEST._serialized_start=148
  _TARGETREQUEST._serialized_end=214
  _LOCATIONSERVICE._serialized_start=217
  _LOCATIONSERVICE._serialized_end=395
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_media_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/assistance/instruction_media_value.proto\x12\x11\x61vikom.assistance\"\x8d\x01\n\x15InstructionMediaValue\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.avikom.assistance.MediaType\x12\x0e\n\x06looped\x18\n \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x0b \x01(\x08*\xe2\x01\n\tMediaType\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x13\n\x0fTYPE_IMAGE_JPEG\x10\x01\x12\x12\n\x0eTYPE_IMAGE_PNG\x10\x02\x12\x12\n\x0eTYPE_VIDEO_MP4\x10\x05\x12\x12\n\x0eTYPE_AUDIO_WAV\x10\n\x12\x12\n\x0eTYPE_AUDIO_MP3\x10\x0b\x12\x18\n\x14TYPE_APPLICATION_PDF\x10\x14\x12\x18\n\x14TYPE_APPLICATION_XML\x10\x15\x12\x13\n\x0fTYPE_TEXT_PLAIN\x10\x1e\x12\x15\n\x11TYPE_WORLD_OBJECT\x10(Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_media_value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _MEDIATYPE._serialized_start=215
  _MEDIATYPE._serialized_end=441
  _INSTRUCTIONMEDIAVALUE._serialized_start=71
  _INSTRUCTIONMEDIAVALUE._serialized_end=212
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.assistance_level_pb2
import avikom.assistance.task_step_pb2
import avikom.generic.user_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StepProficiency(google.protobuf.message.Message):
    """*
    A message to describe the step proficiency of a user. 
    This includes the currently required assistance level but also parameters to determine when or if AVIKOM will attempt to reduce the assistance level.
    @author: Alexander Neumann <alneuma@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUIRED_ASSISTANCE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    TENDENCY_FIELD_NUMBER: builtins.int
    ASSISTANCE_DECREASE_FIELD_NUMBER: builtins.int
    MINIMAL_ASSISTANCE_FIELD_NUMBER: builtins.int
    required_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType
    """/ currently required assistance"""
    @property
    def user(self) -> avikom.generic.user_pb2.User:
        """/ user requiring assistance"""
    @property
    def step(self) -> avikom.assistance.task_step_pb2.TaskStep:
        """/ task step to assist"""
    tendency: builtins.float
    """/ tendency of the current assistance level; raning from -1 to +1"""
    assistance_decrease: builtins.float
    """/ factor to reduce `tendency` when a task was conducted successfully"""
    minimal_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType
    """/ when this level is reached, assistance will not decay any further"""
    def __init__(
        self,
        *,
        required_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType = ...,
        user: avikom.generic.user_pb2.User | None = ...,
        step: avikom.assistance.task_step_pb2.TaskStep | None = ...,
        tendency: builtins.float = ...,
        assistance_decrease: builtins.float = ...,
        minimal_assistance: avikom.assistance.assistance_level_pb2.AssistanceLevel.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["step", b"step", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assistance_decrease", b"assistance_decrease", "minimal_assistance", b"minimal_assistance", "required_assistance", b"required_assistance", "step", b"step", "tendency", b"tendency", "user", b"user"]) -> None: ...

global___StepProficiency = StepProficiency



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/functional_sound.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/headset/functional_sound.proto\x12\x0e\x61vikom.headset*\x85\x03\n\x0f\x46unctionalSound\x12\x11\n\rSOUND_DEFAULT\x10\x00\x12\x12\n\x0eSOUND_GUIDANCE\x10\x01\x12\x1a\n\x16SOUND_INSTRUCTION_INFO\x10\x02\x12\x1b\n\x17SOUND_INSTRUCTION_ALERT\x10\x03\x12\x1b\n\x17SOUND_INSTRUCTION_ALARM\x10\x04\x12\x0f\n\x0bSOUND_ERROR\x10\x05\x12\x18\n\x14SOUND_TASK_COMPLETED\x10\x06\x12\x1e\n\x1aSOUND_SYSTEM_PROGRESS_WAIT\x10\x07\x12\x1e\n\x1aSOUND_NEXT_STEP_IN_BROWSER\x10\x08\x12\"\n\x1eSOUND_PREVIOUS_STEP_IN_BROWSER\x10\t\x12\x15\n\x11SOUND_BUTTON_DOWN\x10\n\x12\x13\n\x0fSOUND_BUTTON_UP\x10\x0b\x12\r\n\tSOUND_TAP\x10\x0c\x12\x15\n\x11SOUND_GRASP_START\x10\r\x12\x14\n\x10SOUND_GRASP_STOP\x10\x0e\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.functional_sound_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _FUNCTIONALSOUND._serialized_start=58
  _FUNCTIONALSOUND._serialized_end=447
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FloatArray(google.protobuf.message.Message):
    """*
    A simple list of floats. Might be used in a variety of context. E.g. as a row to a matrix.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """/ list of floating point numbers"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___FloatArray = FloatArray



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.instruction_media_pb2
import avikom.assistance.instruction_text_pb2
import avikom.assistance.task_stereotype_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TaskStep(google.protobuf.message.Message):
    """*
    This message describes a task step. A step describes an individual operation of a certain stereotype that 
    should be compatible with the 'Basic Action Concept' (BAC) of SDA-M.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    INSTRUCTIONS_FIELD_NUMBER: builtins.int
    MEDIA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ globally unique step name"""
    @property
    def type(self) -> avikom.assistance.task_stereotype_pb2.TaskStereotype:
        """/ defines the kind of action to be conducted; defines the possible actions a user may conduct to process this step"""
    @property
    def instructions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.instruction_text_pb2.InstructionText]:
        """/ textual instructions for this task step"""
    @property
    def media(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.instruction_media_pb2.InstructionMedia]:
        """/ media content for this task step, includes prefabs and such a like"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: avikom.assistance.task_stereotype_pb2.TaskStereotype | None = ...,
        instructions: collections.abc.Iterable[avikom.assistance.instruction_text_pb2.InstructionText] | None = ...,
        media: collections.abc.Iterable[avikom.assistance.instruction_media_pb2.InstructionMedia] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instructions", b"instructions", "media", b"media", "name", b"name", "type", b"type"]) -> None: ...

global___TaskStep = TaskStep



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_text.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import instruction_meta_pb2 as avikom_dot_assistance_dot_instruction__meta__pb2
from avikom.assistance import instruction_text_value_pb2 as avikom_dot_assistance_dot_instruction__text__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/instruction_text.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/instruction_meta.proto\x1a.avikom/assistance/instruction_text_value.proto\"\xef\x01\n\x0fInstructionText\x12\x30\n\x04meta\x18\x01 \x01(\x0b\x32\".avikom.assistance.InstructionMeta\x12\x36\n\rcontent_style\x18\n \x01(\x0e\x32\x1f.avikom.assistance.ContentStyle\x12\x38\n\x07\x63ontent\x18\x0b \x01(\x0b\x32\'.avikom.assistance.InstructionTextValue\x12\x38\n\x07preview\x18\x0c \x01(\x0b\x32\'.avikom.assistance.InstructionTextValue*{\n\x0c\x43ontentStyle\x12\x11\n\rSTYLE_UNKNOWN\x10\x00\x12\x0e\n\nSTYLE_INFO\x10\x01\x12\x11\n\rSTYLE_WARNING\x10\x02\x12\x12\n\x0eSTYLE_CRITICAL\x10\x03\x12\x10\n\x0cSTYLE_SUCESS\x10\x04\x12\x0f\n\x0bSTYLE_ERROR\x10\x05\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_text_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _CONTENTSTYLE._serialized_start=395
  _CONTENTSTYLE._serialized_end=518
  _INSTRUCTIONTEXT._serialized_start=154
  _INSTRUCTIONTEXT._serialized_end=393
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import stream_request_pb2 as avikom_dot_generic_dot_stream__request__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class StreamRequestServiceStub(object):
    """*

    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitStream = channel.unary_unary(
                '/avikom.generic.StreamRequestService/InitStream',
                request_serializer=avikom_dot_generic_dot_stream__request__pb2.StreamRequest.SerializeToString,
                response_deserializer=avikom_dot_generic_dot_peer__pb2.Peer.FromString,
                )
        self.CloseStream = channel.unary_unary(
                '/avikom.generic.StreamRequestService/CloseStream',
                request_serializer=avikom_dot_generic_dot_stream__request__pb2.StreamRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class StreamRequestServiceServicer(object):
    """*

    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    def InitStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamRequestServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitStream': grpc.unary_unary_rpc_method_handler(
                    servicer.InitStream,
                    request_deserializer=avikom_dot_generic_dot_stream__request__pb2.StreamRequest.FromString,
                    response_serializer=avikom_dot_generic_dot_peer__pb2.Peer.SerializeToString,
            ),
            'CloseStream': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseStream,
                    request_deserializer=avikom_dot_generic_dot_stream__request__pb2.StreamRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'avikom.generic.StreamRequestService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamRequestService(object):
    """*

    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    @staticmethod
    def InitStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.StreamRequestService/InitStream',
            avikom_dot_generic_dot_stream__request__pb2.StreamRequest.SerializeToString,
            avikom_dot_generic_dot_peer__pb2.Peer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/avikom.generic.StreamRequestService/CloseStream',
            avikom_dot_generic_dot_stream__request__pb2.StreamRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/game_object_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&avikom/unity/game_object_service.proto\x12\x0c\x61vikom.unity\x1a\x1b\x61vikom/generic/result.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1f\x61vikom/unity/asset_bundle.proto\"\x1f\n\x0fGameObjectQuery\x12\x0c\n\x04name\x18\x01 \x01(\t2\xf4\x02\n\x11GameObjectService\x12W\n\x03\x41\x64\x64\x12\x18.avikom.unity.GameObject\x1a\x16.avikom.generic.Result\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/glasses/objects:\x01*\x12^\n\x03Set\x12\x18.avikom.unity.GameObject\x1a\x16.avikom.generic.Result\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/glasses/objects/{name}:\x01*\x12\x62\n\x03Get\x12\x1d.avikom.unity.GameObjectQuery\x1a\x18.avikom.unity.GameObject\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/glasses/objects/{name}\x12\x42\n\tAddBundle\x12\x19.avikom.unity.AssetBundle\x1a\x16.avikom.generic.Result\"\x00(\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.game_object_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _GAMEOBJECTSERVICE.methods_by_name['Add']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Add']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/glasses/objects:\001*'
  _GAMEOBJECTSERVICE.methods_by_name['Set']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Set']._serialized_options = b'\202\323\344\223\002\037\"\032/v1/glasses/objects/{name}:\001*'
  _GAMEOBJECTSERVICE.methods_by_name['Get']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/glasses/objects/{name}'
  _GAMEOBJECTQUERY._serialized_start=180
  _GAMEOBJECTQUERY._serialized_end=211
  _GAMEOBJECTSERVICE._serialized_start=214
  _GAMEOBJECTSERVICE._serialized_end=586
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/rasa_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.headset import rasa_message_pb2 as avikom_dot_headset_dot_rasa__message__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/headset/rasa_service.proto\x12\x0e\x61vikom.headset\x1a!avikom/headset/rasa_message.proto\x1a\x1b\x61vikom/generic/result.proto\"\x1c\n\tRasaQuery\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\"\x1d\n\nRasaResult\x12\x0f\n\x07intents\x18\x01 \x03(\t2\x98\x01\n\x0bRasaService\x12\x42\n\tSetIntent\x12\x1b.avikom.headset.RasaMessage\x1a\x16.avikom.generic.Result\"\x00\x12\x45\n\nGetIntents\x12\x19.avikom.headset.RasaQuery\x1a\x1a.avikom.headset.RasaResult\"\x00\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.rasa_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _RASAQUERY._serialized_start=117
  _RASAQUERY._serialized_end=145
  _RASARESULT._serialized_start=147
  _RASARESULT._serialized_end=176
  _RASASERVICE._serialized_start=179
  _RASASERVICE._serialized_end=331
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstructionTextValue(google.protobuf.message.Message):
    """*
    The actual value of a text instruction in different representations
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAIN_FIELD_NUMBER: builtins.int
    SSML_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    plain: builtins.str
    """/ value as plain text"""
    ssml: builtins.str
    """/ value with Speech Synthesis Markup Language annotation"""
    html: builtins.str
    """/ value with HTML annotation"""
    def __init__(
        self,
        *,
        plain: builtins.str = ...,
        ssml: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["html", b"html", "plain", b"plain", "ssml", b"ssml"]) -> None: ...

global___InstructionTextValue = InstructionTextValue



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ChoiceItem(google.protobuf.message.Message):
    """*
    This message represents a choice a user can select. It is commonly part of a selection of choices 
    in a ChoiceConfig.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    value: builtins.str
    """/ The value a peer should return when a user made a choice."""
    label: builtins.str
    """/ If set, present this (human readable) label instead of the actual choice value to the user."""
    selected: builtins.bool
    """/ Represents the current selection state of the item."""
    disabled: builtins.bool
    """/ Whether this item can currently be selected or not. Note that `true` also means an item cannot be deselected."""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        label: builtins.str = ...,
        selected: builtins.bool = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "label", b"label", "selected", b"selected", "value", b"value"]) -> None: ...

global___ChoiceItem = ChoiceItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MediaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TYPE_UNKNOWN: _MediaType.ValueType  # 0
    TYPE_IMAGE_JPEG: _MediaType.ValueType  # 1
    TYPE_IMAGE_PNG: _MediaType.ValueType  # 2
    TYPE_VIDEO_MP4: _MediaType.ValueType  # 5
    TYPE_AUDIO_WAV: _MediaType.ValueType  # 10
    TYPE_AUDIO_MP3: _MediaType.ValueType  # 11
    TYPE_APPLICATION_PDF: _MediaType.ValueType  # 20
    TYPE_APPLICATION_XML: _MediaType.ValueType  # 21
    TYPE_TEXT_PLAIN: _MediaType.ValueType  # 30
    TYPE_WORLD_OBJECT: _MediaType.ValueType  # 40

class MediaType(_MediaType, metaclass=_MediaTypeEnumTypeWrapper):
    """*
    Defines the (MIME) type of a media instruction.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

TYPE_UNKNOWN: MediaType.ValueType  # 0
TYPE_IMAGE_JPEG: MediaType.ValueType  # 1
TYPE_IMAGE_PNG: MediaType.ValueType  # 2
TYPE_VIDEO_MP4: MediaType.ValueType  # 5
TYPE_AUDIO_WAV: MediaType.ValueType  # 10
TYPE_AUDIO_MP3: MediaType.ValueType  # 11
TYPE_APPLICATION_PDF: MediaType.ValueType  # 20
TYPE_APPLICATION_XML: MediaType.ValueType  # 21
TYPE_TEXT_PLAIN: MediaType.ValueType  # 30
TYPE_WORLD_OBJECT: MediaType.ValueType  # 40
global___MediaType = MediaType

@typing_extensions.final
class InstructionMediaValue(google.protobuf.message.Message):
    """*
    The actual value of a media instruction. Only one field should be set.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    LOOPED_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """/ a local ressource identifier; resolution is receiver-specific"""
    url: builtins.str
    """/ a global reference to a ressource; should be taken literally"""
    data: builtins.bytes
    """/ the media file as a data stream"""
    type: global___MediaType.ValueType
    """/ type hint for this media value"""
    looped: builtins.bool
    """/ determines whether a media file should be looped (if playable)"""
    autoplay: builtins.bool
    """/ determines whether a media file should be opened/executed right away"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        url: builtins.str = ...,
        data: builtins.bytes = ...,
        type: global___MediaType.ValueType = ...,
        looped: builtins.bool = ...,
        autoplay: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoplay", b"autoplay", "data", b"data", "looped", b"looped", "type", b"type", "uri", b"uri", "url", b"url"]) -> None: ...

global___InstructionMediaValue = InstructionMediaValue



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.instruction_media_value_pb2
import avikom.assistance.instruction_meta_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstructionMedia(google.protobuf.message.Message):
    """*
    This message describes a media instruction. This includes the instruction's (MIME) type and either an URI or the media as a binary stream.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> avikom.assistance.instruction_meta_pb2.InstructionMeta: ...
    @property
    def content(self) -> avikom.assistance.instruction_media_value_pb2.InstructionMediaValue: ...
    @property
    def preview(self) -> avikom.assistance.instruction_media_value_pb2.InstructionMediaValue: ...
    def __init__(
        self,
        *,
        meta: avikom.assistance.instruction_meta_pb2.InstructionMeta | None = ...,
        content: avikom.assistance.instruction_media_value_pb2.InstructionMediaValue | None = ...,
        preview: avikom.assistance.instruction_media_value_pb2.InstructionMediaValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "meta", b"meta", "preview", b"preview"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "meta", b"meta", "preview", b"preview"]) -> None: ...

global___InstructionMedia = InstructionMedia



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tunnel/message_tunnel_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.tunnel import server_to_client_pb2 as avikom_dot_tunnel_dot_server__to__client__pb2
from avikom.tunnel import client_to_server_pb2 as avikom_dot_tunnel_dot_client__to__server__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*avikom/tunnel/message_tunnel_service.proto\x12\ravikom.tunnel\x1a$avikom/tunnel/server_to_client.proto\x1a$avikom/tunnel/client_to_server.proto2n\n\x14MessageTunnelService\x12V\n\x10RegisterTunneled\x12\x1d.avikom.tunnel.ClientToServer\x1a\x1d.avikom.tunnel.ServerToClient\"\x00(\x01\x30\x01\x42i\n\x17\x61pp.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\xaa\x02\x13\x41vikom.Types.Tunnelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tunnel.message_tunnel_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\252\002\023Avikom.Types.Tunnel'
  _MESSAGETUNNELSERVICE._serialized_start=137
  _MESSAGETUNNELSERVICE._serialized_end=247
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FunctionalSound:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FunctionalSoundEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FunctionalSound.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SOUND_DEFAULT: _FunctionalSound.ValueType  # 0
    """/ generates no output"""
    SOUND_GUIDANCE: _FunctionalSound.ValueType  # 1
    """/ should be used when trying to guide the user to specific location"""
    SOUND_INSTRUCTION_INFO: _FunctionalSound.ValueType  # 2
    """/ should be used for instructions with ContentStyle "INFO" """
    SOUND_INSTRUCTION_ALERT: _FunctionalSound.ValueType  # 3
    """/ should be used for instructions with ContentStyle "WARNING" """
    SOUND_INSTRUCTION_ALARM: _FunctionalSound.ValueType  # 4
    """/ should be used for instructions with ContentStyle "CRITICAL" """
    SOUND_ERROR: _FunctionalSound.ValueType  # 5
    """/ should be used when notifying a user that an error occured"""
    SOUND_TASK_COMPLETED: _FunctionalSound.ValueType  # 6
    """/ should be used for providing positive feedback in key moments (i.e. on completion of a task)"""
    SOUND_SYSTEM_PROGRESS_WAIT: _FunctionalSound.ValueType  # 7
    """/ should be used to notify user that the system is processing user input"""
    SOUND_NEXT_STEP_IN_BROWSER: _FunctionalSound.ValueType  # 8
    """/ should be used when next step is shown in step browser"""
    SOUND_PREVIOUS_STEP_IN_BROWSER: _FunctionalSound.ValueType  # 9
    """/ should be used when previous step is shown in step browser"""
    SOUND_BUTTON_DOWN: _FunctionalSound.ValueType  # 10
    """/ should be used when user presses a button"""
    SOUND_BUTTON_UP: _FunctionalSound.ValueType  # 11
    """/ shuold be used when user lifts button press"""
    SOUND_TAP: _FunctionalSound.ValueType  # 12
    """/ should be used when user taps"""
    SOUND_GRASP_START: _FunctionalSound.ValueType  # 13
    """/ should be used when user grasps a virtual object"""
    SOUND_GRASP_STOP: _FunctionalSound.ValueType  # 14
    """/ should be used when user releases a a virtual object"""

class FunctionalSound(_FunctionalSound, metaclass=_FunctionalSoundEnumTypeWrapper):
    """*
    This enum describes common functional sounds that can be played back on an auditory peer
    to provide feedback to a user.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

SOUND_DEFAULT: FunctionalSound.ValueType  # 0
"""/ generates no output"""
SOUND_GUIDANCE: FunctionalSound.ValueType  # 1
"""/ should be used when trying to guide the user to specific location"""
SOUND_INSTRUCTION_INFO: FunctionalSound.ValueType  # 2
"""/ should be used for instructions with ContentStyle "INFO" """
SOUND_INSTRUCTION_ALERT: FunctionalSound.ValueType  # 3
"""/ should be used for instructions with ContentStyle "WARNING" """
SOUND_INSTRUCTION_ALARM: FunctionalSound.ValueType  # 4
"""/ should be used for instructions with ContentStyle "CRITICAL" """
SOUND_ERROR: FunctionalSound.ValueType  # 5
"""/ should be used when notifying a user that an error occured"""
SOUND_TASK_COMPLETED: FunctionalSound.ValueType  # 6
"""/ should be used for providing positive feedback in key moments (i.e. on completion of a task)"""
SOUND_SYSTEM_PROGRESS_WAIT: FunctionalSound.ValueType  # 7
"""/ should be used to notify user that the system is processing user input"""
SOUND_NEXT_STEP_IN_BROWSER: FunctionalSound.ValueType  # 8
"""/ should be used when next step is shown in step browser"""
SOUND_PREVIOUS_STEP_IN_BROWSER: FunctionalSound.ValueType  # 9
"""/ should be used when previous step is shown in step browser"""
SOUND_BUTTON_DOWN: FunctionalSound.ValueType  # 10
"""/ should be used when user presses a button"""
SOUND_BUTTON_UP: FunctionalSound.ValueType  # 11
"""/ shuold be used when user lifts button press"""
SOUND_TAP: FunctionalSound.ValueType  # 12
"""/ should be used when user taps"""
SOUND_GRASP_START: FunctionalSound.ValueType  # 13
"""/ should be used when user grasps a virtual object"""
SOUND_GRASP_STOP: FunctionalSound.ValueType  # 14
"""/ should be used when user releases a a virtual object"""
global___FunctionalSound = FunctionalSound



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/camera_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n avikom/vision/camera_state.proto\x12\ravikom.vision*L\n\x0b\x43\x61meraState\x12\x0f\n\x0bUNALLOCATED\x10\x00\x12\x0b\n\x07VUFORIA\x10\x01\x12\x0b\n\x07WEB_RTC\x10\x02\x12\x12\n\x0eSPECTATOR_VIEW\x10\x03*b\n\rCameraTrigger\x12\x0b\n\x07RELEASE\x10\x00\x12\x13\n\x0f\x41\x43QUIRE_VUFORIA\x10\x01\x12\x13\n\x0f\x41\x43QUIRE_WEB_RTC\x10\x02\x12\x1a\n\x16\x41\x43QUIRE_SPECTATOR_VIEW\x10\x03\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.camera_state_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _CAMERASTATE._serialized_start=51
  _CAMERASTATE._serialized_end=127
  _CAMERATRIGGER._serialized_start=129
  _CAMERATRIGGER._serialized_end=227
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RpcEndpoint:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RpcEndpointEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RpcEndpoint.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ENDPOINT_UNKNOWN: _RpcEndpoint.ValueType  # 0
    """/ default; should not be used actively"""
    ENDPOINT_SCENE_CONSUMER: _RpcEndpoint.ValueType  # 1
    """/ peer implements SceneConsumerService"""
    ENDPOINT_MEDIA_FOLLOWER: _RpcEndpoint.ValueType  # 2
    """/ peer implements MediaFollowerService"""
    ENDPOINT_REMOTE_CONTROL: _RpcEndpoint.ValueType  # 3
    """/ peer implements RemoteControlService"""
    ENDPOINT_AUDIO_PEER_CONTROL: _RpcEndpoint.ValueType  # 4
    """/ peer implements AudioPeerControlService"""
    ENDPOINT_GAZE: _RpcEndpoint.ValueType  # 5
    """/ peer implements GazeService"""
    ENDPOINT_IMAGE: _RpcEndpoint.ValueType  # 6
    """/ peer implements ImageService"""
    ENDPOINT_LOCATION: _RpcEndpoint.ValueType  # 7
    """/ provides relative position of an object to a target object; peer implements LocationService"""
    ENDPOINT_INTERACTION_EVENT: _RpcEndpoint.ValueType  # 8
    """/ peer implements InteractionEventService"""
    ENDPOINT_SERVICE_PROVIDER: _RpcEndpoint.ValueType  # 9
    """/ peer implements ServiceProviderService"""
    ENDPOINT_RUNTIME_STEP_CONSUMER: _RpcEndpoint.ValueType  # 10
    """/ peer implements RuntimeStepConsumerService"""

class RpcEndpoint(_RpcEndpoint, metaclass=_RpcEndpointEnumTypeWrapper):
    """*
    Indicates the RPC endpoints a peer implements/provides.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

ENDPOINT_UNKNOWN: RpcEndpoint.ValueType  # 0
"""/ default; should not be used actively"""
ENDPOINT_SCENE_CONSUMER: RpcEndpoint.ValueType  # 1
"""/ peer implements SceneConsumerService"""
ENDPOINT_MEDIA_FOLLOWER: RpcEndpoint.ValueType  # 2
"""/ peer implements MediaFollowerService"""
ENDPOINT_REMOTE_CONTROL: RpcEndpoint.ValueType  # 3
"""/ peer implements RemoteControlService"""
ENDPOINT_AUDIO_PEER_CONTROL: RpcEndpoint.ValueType  # 4
"""/ peer implements AudioPeerControlService"""
ENDPOINT_GAZE: RpcEndpoint.ValueType  # 5
"""/ peer implements GazeService"""
ENDPOINT_IMAGE: RpcEndpoint.ValueType  # 6
"""/ peer implements ImageService"""
ENDPOINT_LOCATION: RpcEndpoint.ValueType  # 7
"""/ provides relative position of an object to a target object; peer implements LocationService"""
ENDPOINT_INTERACTION_EVENT: RpcEndpoint.ValueType  # 8
"""/ peer implements InteractionEventService"""
ENDPOINT_SERVICE_PROVIDER: RpcEndpoint.ValueType  # 9
"""/ peer implements ServiceProviderService"""
ENDPOINT_RUNTIME_STEP_CONSUMER: RpcEndpoint.ValueType  # 10
"""/ peer implements RuntimeStepConsumerService"""
global___RpcEndpoint = RpcEndpoint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.runtime_task_step_pb2
import avikom.assistance.scene_pb2
import avikom.assistance.task_pb2
import avikom.generic.modality_pb2
import avikom.generic.peer_pb2
import avikom.generic.user_profile_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Session(google.protobuf.message.Message):
    """
    A (serializable) version of a session.
    Data should only be stored in json format if the represented data cannot be generalized.
    Note that sessions might contain temporal data that cannot be stored because of their short-times lifespan or due to serializiation limitations.
    For these cases, separate setup and tear down strategies should be considered.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    PEERS_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    MODAL_AFFINITY_FIELD_NUMBER: builtins.int
    JSON_DATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ session ID; generated by `SessionService`"""
    @property
    def scene(self) -> avikom.assistance.scene_pb2.Scene:
        """/ current scene; only the scene unique identifier (name) must be provided"""
    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.peer_pb2.Peer]:
        """/ a list of peers available in the session; only the unique identifier (name) must be provided"""
    @property
    def current(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep]:
        """/ list of currently eligible `RuntimeTaskSteps`"""
    @property
    def profile(self) -> avikom.generic.user_profile_pb2.UserProfile:
        """/ profile of the session's user"""
    @property
    def task(self) -> avikom.assistance.task_pb2.Task:
        """/ currently conducted task"""
    @property
    def modal_affinity(self) -> avikom.generic.modality_pb2.Modality:
        """/ environmental factors of the session's context"""
    json_data: builtins.str
    """/ used for session/task-specific data;"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        scene: avikom.assistance.scene_pb2.Scene | None = ...,
        peers: collections.abc.Iterable[avikom.generic.peer_pb2.Peer] | None = ...,
        current: collections.abc.Iterable[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep] | None = ...,
        profile: avikom.generic.user_profile_pb2.UserProfile | None = ...,
        task: avikom.assistance.task_pb2.Task | None = ...,
        modal_affinity: avikom.generic.modality_pb2.Modality | None = ...,
        json_data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["modal_affinity", b"modal_affinity", "profile", b"profile", "scene", b"scene", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "id", b"id", "json_data", b"json_data", "modal_affinity", b"modal_affinity", "peers", b"peers", "profile", b"profile", "scene", b"scene", "task", b"task"]) -> None: ...

global___Session = Session



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/game_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import transpose_pb2 as avikom_dot_unity_dot_transpose__pb2
from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/unity/game_object.proto\x12\x0c\x61vikom.unity\x1a\x1c\x61vikom/unity/transpose.proto\x1a\x1f\x61vikom/unity/asset_bundle.proto\"\x92\x01\n\nGameObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\ttranspose\x18\x02 \x01(\x0b\x32\x17.avikom.unity.Transpose\x12\x0e\n\x06prefab\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12*\n\x08\x63hildren\x18\x05 \x03(\x0b\x32\x18.avikom.unity.GameObjectBf\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.game_object_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _GAMEOBJECT._serialized_start=112
  _GAMEOBJECT._serialized_end=258
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.scene_pb2
import avikom.assistance.task_pb2
import avikom.generic.key_value_pair_pb2
import avikom.generic.user_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IssueStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IssueStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IssueStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ISSUE_UNKNOWN: _IssueStatus.ValueType  # 0
    """/ default; should not be set explicitely"""
    ISSUE_OPEN: _IssueStatus.ValueType  # 1
    """/ issue needs to be resolved"""
    ISSUE_ASSIGNED: _IssueStatus.ValueType  # 5
    """/ issue has been assigned to a user"""
    ISSUE_ACTIVE: _IssueStatus.ValueType  # 7
    """/ issue is currently resolved by a user"""
    ISSUE_CLOSED: _IssueStatus.ValueType  # 10
    """/ issue has been resolved"""
    ISSUE_REJECTED: _IssueStatus.ValueType  # 11
    """/ issue cannot be resolved or has been declined"""

class IssueStatus(_IssueStatus, metaclass=_IssueStatusEnumTypeWrapper):
    """*
    The status of an issue. Can be used to find unresolved tasks and filter issue lists.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

ISSUE_UNKNOWN: IssueStatus.ValueType  # 0
"""/ default; should not be set explicitely"""
ISSUE_OPEN: IssueStatus.ValueType  # 1
"""/ issue needs to be resolved"""
ISSUE_ASSIGNED: IssueStatus.ValueType  # 5
"""/ issue has been assigned to a user"""
ISSUE_ACTIVE: IssueStatus.ValueType  # 7
"""/ issue is currently resolved by a user"""
ISSUE_CLOSED: IssueStatus.ValueType  # 10
"""/ issue has been resolved"""
ISSUE_REJECTED: IssueStatus.ValueType  # 11
"""/ issue cannot be resolved or has been declined"""
global___IssueStatus = IssueStatus

@typing_extensions.final
class Issue(google.protobuf.message.Message):
    """*
    An message that contains informations about (postponed) tasks and their state.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    INCLUDE_FIELD_NUMBER: builtins.int
    EXCLUDE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ id of a task; must be set for creation!"""
    @property
    def issuer(self) -> avikom.generic.user_pb2.User:
        """/ who issued the task"""
    description: builtins.str
    """/ an optional text message"""
    @property
    def scene(self) -> avikom.assistance.scene_pb2.Scene:
        """/ location where the task needs to be conducted"""
    @property
    def task(self) -> avikom.assistance.task_pb2.Task:
        """/ the task to be done"""
    @property
    def include(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.user_pb2.User]:
        """/ users that are eligible for that task"""
    @property
    def exclude(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.user_pb2.User]:
        """/ users that should not be eligible for that issue; only considered when include is empty"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ this is passed to camunda"""
    status: global___IssueStatus.ValueType
    """/ status of the issue"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        issuer: avikom.generic.user_pb2.User | None = ...,
        description: builtins.str = ...,
        scene: avikom.assistance.scene_pb2.Scene | None = ...,
        task: avikom.assistance.task_pb2.Task | None = ...,
        include: collections.abc.Iterable[avikom.generic.user_pb2.User] | None = ...,
        exclude: collections.abc.Iterable[avikom.generic.user_pb2.User] | None = ...,
        parameters: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
        status: global___IssueStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["issuer", b"issuer", "scene", b"scene", "task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "exclude", b"exclude", "id", b"id", "include", b"include", "issuer", b"issuer", "parameters", b"parameters", "scene", b"scene", "status", b"status", "task", b"task"]) -> None: ...

global___Issue = Issue

@typing_extensions.final
class IssueList(google.protobuf.message.Message):
    """*
    A collection of `Issue` objects.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUES_FIELD_NUMBER: builtins.int
    @property
    def issues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Issue]: ...
    def __init__(
        self,
        *,
        issues: collections.abc.Iterable[global___Issue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["issues", b"issues"]) -> None: ...

global___IssueList = IssueList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/step_proficiency_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import step_proficiency_pb2 as avikom_dot_assistance_dot_step__proficiency__pb2
from avikom.assistance import split_procedure_result_pb2 as avikom_dot_assistance_dot_split__procedure__result__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8avikom/assistance/step_proficiency_storage_service.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/step_proficiency.proto\x1a.avikom/assistance/split_procedure_result.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\"<\n\x14StepProficiencyQuery\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x13\n\x0btarget_name\x18\x02 \x01(\t2\xf5\x04\n\x1dStepProficiencyStorageService\x12\xa6\x01\n\x12GetStepProficiency\x12\'.avikom.assistance.StepProficiencyQuery\x1a\".avikom.assistance.StepProficiency\"C\x82\xd3\xe4\x93\x02=\x12;/v1/storage/step_proficiencies/step/{target_name}/{user_id}\x12{\n\x12SetStepProficiency\x12\".avikom.assistance.StepProficiency\x1a\x16.avikom.generic.Result\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/storage/step_proficiencies:\x01*\x12\xa8\x01\n\x17GetSplitProcedureResult\x12\'.avikom.assistance.StepProficiencyQuery\x1a\'.avikom.assistance.SplitProcedureResult\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/storage/split_procedure/{target_name}/{user_id}\x12\x82\x01\n\x17SetSplitProcedureResult\x12\'.avikom.assistance.SplitProcedureResult\x1a\x16.avikom.generic.Result\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/storage/split_procedure:\x01*Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.step_proficiency_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetStepProficiency']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetStepProficiency']._serialized_options = b'\202\323\344\223\002=\022;/v1/storage/step_proficiencies/step/{target_name}/{user_id}'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetStepProficiency']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetStepProficiency']._serialized_options = b'\202\323\344\223\002#\"\036/v1/storage/step_proficiencies:\001*'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetSplitProcedureResult']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetSplitProcedureResult']._serialized_options = b'\202\323\344\223\0025\0223/v1/storage/split_procedure/{target_name}/{user_id}'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetSplitProcedureResult']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetSplitProcedureResult']._serialized_options = b'\202\323\344\223\002 \"\033/v1/storage/split_procedure:\001*'
  _STEPPROFICIENCYQUERY._serialized_start=228
  _STEPPROFICIENCYQUERY._serialized_end=288
  _STEPPROFICIENCYSTORAGESERVICE._serialized_start=291
  _STEPPROFICIENCYSTORAGESERVICE._serialized_end=920
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RuntimeStepState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RuntimeStepStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RuntimeStepState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNKNOWN: _RuntimeStepState.ValueType  # 0
    """/ default; might be treated as an error; should not be set explicitely"""
    STATE_CREATED: _RuntimeStepState.ValueType  # 1
    """/ An RTS has been created. This is usually not communicated to peers/consumers."""
    STATE_PENDING: _RuntimeStepState.ValueType  # 5
    """/ The task has been communicated to consumers and now needs to be resolved."""
    STATE_COMPLETED: _RuntimeStepState.ValueType  # 10
    """/ RTS has been completeted successfully"""
    STATE_FINAL: _RuntimeStepState.ValueType  # 11
    """/ RTS process ended with this step"""
    STATE_FAILED: _RuntimeStepState.ValueType  # 15
    """/ RTS processing failed"""
    STATE_CANCELLED: _RuntimeStepState.ValueType  # 20
    """/ RTS became invalid and has been cancelled"""
    STATE_ERROR: _RuntimeStepState.ValueType  # 25
    """/ An error that is not a cause of process- or consumer-related issues."""

class RuntimeStepState(_RuntimeStepState, metaclass=_RuntimeStepStateEnumTypeWrapper):
    """*
    A step state resembled an `IssueState` in many cases but is more detailed.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

STATE_UNKNOWN: RuntimeStepState.ValueType  # 0
"""/ default; might be treated as an error; should not be set explicitely"""
STATE_CREATED: RuntimeStepState.ValueType  # 1
"""/ An RTS has been created. This is usually not communicated to peers/consumers."""
STATE_PENDING: RuntimeStepState.ValueType  # 5
"""/ The task has been communicated to consumers and now needs to be resolved."""
STATE_COMPLETED: RuntimeStepState.ValueType  # 10
"""/ RTS has been completeted successfully"""
STATE_FINAL: RuntimeStepState.ValueType  # 11
"""/ RTS process ended with this step"""
STATE_FAILED: RuntimeStepState.ValueType  # 15
"""/ RTS processing failed"""
STATE_CANCELLED: RuntimeStepState.ValueType  # 20
"""/ RTS became invalid and has been cancelled"""
STATE_ERROR: RuntimeStepState.ValueType  # 25
"""/ An error that is not a cause of process- or consumer-related issues."""
global___RuntimeStepState = RuntimeStepState
